# yamm

[![Build Status](https://travis-ci.org/inkeye/yamm.svg?branch=master)](https://travis-ci.org/inkeye/yamm)
[![Coverage Status](https://coveralls.io/repos/github/inkeye/yamm/badge.svg?branch=master)](https://coveralls.io/github/inkeye/yamm?branch=master)

yet another markov module
